@@ -1,6 +1,6 @@
 /* -*- C++ -*-
  * File: libraw_datastream.cpp
- * Copyright 2008-2013 LibRaw LLC (info@libraw.org)
+ * Copyright 2008-2015 LibRaw LLC (info@libraw.org)
  *
  * LibRaw C++ interface (implementation)
 
@@ -29,7 +29,6 @@
 #include "libraw/libraw_types.h"
 #include "libraw/libraw.h"
 #include "libraw/libraw_datastream.h"
-#include "internal/libraw_bytebuffer.h"
 #include <sys/stat.h>
 #ifdef USE_JASPER
 #include <jasper/jasper.h>	/* Decode RED camera movies */
@@ -42,38 +41,6 @@
 #define NO_JPEG
 #endif
 
-
-LibRaw_byte_buffer::LibRaw_byte_buffer(unsigned sz) 
-{ 
-    buf=0; size=sz; offt=0; do_free=0; 
-    if(size)
-        { 
-            buf = (unsigned char*)malloc(size); do_free=1;
-        }
-}
-
-void LibRaw_byte_buffer::set_buffer(void *bb, unsigned int sz) 
-{ 
-    buf = (unsigned char*)bb; size = sz; offt=0; do_free=0;
-}
-
-LibRaw_byte_buffer::~LibRaw_byte_buffer() 
-{ 
-    if(do_free) free(buf);
-}
-
-LibRaw_byte_buffer *LibRaw_abstract_datastream::make_byte_buffer(unsigned int sz)
-{
-  if(INT64(sz)>size())
-    throw LIBRAW_EXCEPTION_IO_CORRUPT;
-
-    LibRaw_byte_buffer *ret = new LibRaw_byte_buffer(sz);
-    if(!ret) // failed new should throw std::exception
-      throw LIBRAW_EXCEPTION_ALLOC;
-    read(ret->get_buffer(),sz,1);
-    return ret;
-}
-
 int LibRaw_abstract_datastream::tempbuffer_open(void  *buf, size_t size)
 {
     if(substream) return EBUSY;
@@ -121,7 +88,7 @@ LibRaw_file_datastream::LibRaw_file_datastream(const char *fname)
       }
     }
 }
-#if defined(WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && defined(_MSC_VER) && (_MSC_VER > 1310)
 LibRaw_file_datastream::LibRaw_file_datastream(const wchar_t *fname) : filename(),wfilename(fname),jas_file(NULL),_fsize(0)
 {
   if (wfilename.size()>0) 
@@ -155,9 +122,9 @@ int LibRaw_file_datastream::read(void * ptr,size_t size, size_t nmemb)
     
 /* Visual Studio 2008 marks sgetn as insecure, but VS2010 does not. */
 #if defined(WIN32SECURECALLS) && (_MSC_VER < 1600)
-    LR_STREAM_CHK(); return int(f->_Sgetn_s(static_cast<char*>(ptr), nmemb * size,nmemb * size) / size); 
+    LR_STREAM_CHK(); return int(f->_Sgetn_s(static_cast<char*>(ptr), nmemb * size,nmemb * size) / (size>0?size:1)); 
 #else
-    LR_STREAM_CHK(); return int(f->sgetn(static_cast<char*>(ptr), std::streamsize(nmemb * size)) / size); 
+    LR_STREAM_CHK(); return int(f->sgetn(static_cast<char*>(ptr), std::streamsize(nmemb * size)) / (size>0?size:1)); 
 #endif
 }
 
@@ -179,7 +146,7 @@ int LibRaw_file_datastream::seek(INT64 o, int whence)
         case SEEK_END: dir = std::ios_base::end; break;
         default: dir = std::ios_base::beg;
         }
-    return (int)f->pubseekoff((long)o, dir)<0?-1:0;
+    return f->pubseekoff((long)o, dir) < 0;
 }
 
 INT64 LibRaw_file_datastream::tell()     
@@ -245,7 +212,7 @@ int LibRaw_file_datastream::subfile_open(const char *fn)
         return 0;
 }
 
-#if defined(WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && defined(_MSC_VER) && (_MSC_VER > 1310)
 int LibRaw_file_datastream::subfile_open(const wchar_t *fn)
 {
 	LR_STREAM_CHK();
@@ -279,7 +246,7 @@ void * LibRaw_file_datastream::make_jas_stream()
 #ifdef NO_JASPER
     return NULL;
 #else
-#if defined(WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && defined(_MSC_VER) && (_MSC_VER > 1310)
 	if(wfname())
 	{
 		jas_file = _wfopen(wfname(),L"rb");
@@ -299,7 +266,7 @@ int LibRaw_file_datastream::jpeg_src(void *jpegdata)
   return -1; // not supported
 #else
   if(jas_file) { fclose(jas_file); jas_file = NULL;}
-#if defined(WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && defined(_MSC_VER) && (_MSC_VER > 1310)
   if(wfname())
     {
       jas_file = _wfopen(wfname(),L"rb");
@@ -339,7 +306,7 @@ int LibRaw_buffer_datastream::read(void * ptr,size_t sz, size_t nmemb)
         return 0;
     memmove(ptr,buf+streampos,to_read);
     streampos+=to_read;
-    return int((to_read+sz-1)/sz);
+    return int((to_read+sz-1)/(sz>0?sz:1));
 }
 
 int LibRaw_buffer_datastream::seek(INT64 o, int whence)
@@ -444,20 +411,6 @@ int LibRaw_buffer_datastream::scanf_one(const char *fmt, void* val)
     return scanf_res;
 }
 
-LibRaw_byte_buffer *LibRaw_buffer_datastream::make_byte_buffer(unsigned int sz)
-{
-  if(INT64(sz)>size())
-    throw LIBRAW_EXCEPTION_IO_CORRUPT;
-
-    LibRaw_byte_buffer *ret = new LibRaw_byte_buffer(0);
-    if(!ret) // failed new should throw std::exception
-      throw LIBRAW_EXCEPTION_ALLOC;
-    if(streampos + sz > streamsize)
-        sz = streamsize - streampos;
-    ret->set_buffer(buf+streampos,sz);
-    return ret;
-}
-
 int LibRaw_buffer_datastream::eof()
 { 
     if(substream) return substream->eof();
@@ -523,7 +476,7 @@ LibRaw_bigfile_datastream::LibRaw_bigfile_datastream(const char *fname): filenam
     sav=0;
 }
 
-#if defined(WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && defined(_MSC_VER) && (_MSC_VER > 1310)
 LibRaw_bigfile_datastream::LibRaw_bigfile_datastream(const wchar_t *fname) : filename(),wfilename(fname)
 { 
   if(wfilename.size()>0)
@@ -637,7 +590,7 @@ int LibRaw_bigfile_datastream::subfile_open(const char *fn)
     else
         return 0;
 }
-#if defined(WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && defined(_MSC_VER) && (_MSC_VER > 1310)
 int LibRaw_bigfile_datastream::subfile_open(const wchar_t *fn)
 {
 	if(sav) return EBUSY;
